Coverage for src/paperap/models/abstract/__init__.py: 100%

1"""

2----------------------------------------------------------------------------

3

4 METADATA:

5

6 File: __init__.py

7 Project: paperap

8 Created: 2025-03-04

9 Version: 0.0.5

10 Author: Jess Mann

11 Email: jess@jmann.me

12 Copyright (c) 2025 Jess Mann

13

14----------------------------------------------------------------------------

15

16 LAST MODIFIED:

17

18 2025-03-04 By Jess Mann

19

20"""

21

22 from paperap.models.abstract.meta import StatusContext

23 from paperap.models.abstract.model import BaseModel, FilteringStrategies, StandardModel

24 from paperap.models.abstract.queryset import BaseQuerySet, StandardQuerySet